var RE = {};

RE.currentSelection = {
    "startContainer": 0,
    "startOffset": 0,
    "endContainer": 0,
    "endOffset": 0};

RE.editor = document.getElementById('editor');

document.addEventListener("selectionchange", function() { RE.backuprange(); });

// Initializations
RE.callback = function() {
    window.location.href = "re-callback://" + encodeURI(RE.getContent());
};

RE.setHtml = function(contents) {
    RE.editor.innerHTML = decodeURIComponent(contents.replace(/\+/g, '%20'));
};

RE.getHtml = function() {
    return RE.editor.innerHTML;
};

RE.getText = function() {
    return RE.editor.innerText;
};

RE.setBaseTextColor = function(color) {
    RE.editor.style.color  = color;
    RE.callback();
};

RE.setBaseFontSize = function(size) {
    RE.editor.style.fontSize = size;
};

RE.setPadding = function(left, top, right, bottom) {
  RE.editor.style.paddingLeft = left;
  RE.editor.style.paddingTop = top;
  RE.editor.style.paddingRight = right;
  RE.editor.style.paddingBottom = bottom;
};

RE.setBackgroundColor = function(color) {
    document.body.style.backgroundColor = color;
};

RE.setBackgroundImage = function(image) {
    RE.editor.style.backgroundImage = image;
};

RE.setWidth = function(size) {
    RE.editor.style.minWidth = size;
};

RE.setHeight = function(size) {
    RE.editor.style.height = size;
};

RE.setTextAlign = function(align) {
    RE.editor.style.textAlign = align;
    RE.callback();
};

RE.setVerticalAlign = function(align) {
    RE.editor.style.verticalAlign = align;
};

RE.setPlaceholder = function(placeholder) {
    RE.editor.setAttribute("placeholder", placeholder);
};

RE.setInputEnabled = function(inputEnabled) {
    RE.editor.contentEditable = String(inputEnabled);
};

RE.undo = function() {
    document.execCommand('undo', false, null);
    RE.callback();
};

RE.redo = function() {
    document.execCommand('redo', false, null);
    RE.callback();
};

RE.setBold = function() {
    document.execCommand('bold', false, null);
    RE.getStatus(RE.getElem().parentNode);
    RE.callback();
};

RE.setItalic = function() {
    document.execCommand('italic', false, null);
    RE.getStatus(RE.getElem().parentNode);
    RE.callback();
};

RE.setSubscript = function() {
    document.execCommand('subscript', false, null);
};

RE.setSuperscript = function() {
    document.execCommand('superscript', false, null);
};

RE.setStrikeThrough = function() {
    document.execCommand('strikeThrough', false, null);
    RE.getStatus(RE.getElem().parentNode);
    RE.callback();
};

RE.setUnderline = function() {
    document.execCommand('underline', false, null);
    RE.getStatus(RE.getElem().parentNode);
    RE.callback();
};

RE.setBullets = function() {
    //document.execCommand('insertUnorderedList', false, null);
    var editor = document.getElementById("editor");
    RE.restorerange();
    if(document.queryCommandState('insertOrderedList')){
        document.execCommand('insertUnorderedList', false, null);
        var uls = $(editor).find("ul");
        uls.css("margin","10px 0 10px 9%");
        uls.css("width","82%");
        uls.css("line-height","27px");
        uls.css("font-size","17px");
        uls.css("color","#323232");
        uls.css("list-style","disc");

        RE.getStatus(RE.getElem().parentNode);
        RE.callback();
        return;
    }
    document.execCommand('insertUnorderedList', false, null);
    // 验证列表是否被包裹在 <p> 之内
    var $selectionElem = RE.getElem().parentNode;
    if ($selectionElem.nodeName === 'LI') {
        $selectionElem = $selectionElem.parentNode;
    }else if($selectionElem.nodeName === 'SPAN') {
        $selectionElem = $selectionElem.parentNode;
        $selectionElem = $selectionElem.parentNode;
    }
    if (/^ol|ul$/i.test($selectionElem.nodeName) === false) {
        return;
    }
    if ($selectionElem === editor) {
        // 证明是顶级标签，没有被 <p> 包裹
        return;
    }
    var $parent = $selectionElem.parentNode;
    if ($parent === editor) {
        // $parent 是顶级标签，不能删除
        return;
    }

    $($selectionElem).insertAfter($parent);
    $parent.remove();

    var uls = $(editor).find("ul");
    uls.css("margin","10px 0 10px 9%");
    uls.css("width","82%");
    uls.css("line-height","27px");
    uls.css("font-size","17px");
    uls.css("color","#323232");
    uls.css("list-style","disc");

    RE.getStatus(RE.getElem().parentNode);
    RE.callback();
};

RE.setNumbers = function() {
    //document.execCommand('insertOrderedList', false, null);
    var editor = document.getElementById("editor");
    RE.restorerange();
    if(document.queryCommandState('insertUnorderedList')){
        document.execCommand('insertOrderedList', false, null);
        var ols = $(editor).find("ol");
        ols.css("margin","10px 0 10px 9%");
        ols.css("width","82%");
        ols.css("line-height","27px");
        ols.css("font-size","17px");
        ols.css("color","#323232");
        ols.css("list-style","decimal");

        RE.getStatus(RE.getElem().parentNode);
        RE.callback();
        return;
    }
    document.execCommand('insertOrderedList', false, null);
    // 验证列表是否被包裹在 <p> 之内
    var $selectionElem = RE.getElem().parentNode;
    if ($selectionElem.nodeName === 'LI') {
        $selectionElem = $selectionElem.parentNode;
    }else if($selectionElem.nodeName === 'SPAN') {
        $selectionElem = $selectionElem.parentNode;
        $selectionElem = $selectionElem.parentNode;
    }
    if (/^ol|ul$/i.test($selectionElem.nodeName) === false) {
        return;
    }
    if ($selectionElem === editor) {
        // 证明是顶级标签，没有被 <p> 包裹
        return;
    }
    var $parent = $selectionElem.parentNode;
    if ($parent === editor) {
        // $parent 是顶级标签，不能删除
        return;
    }

    $($selectionElem).insertAfter($parent);
    $parent.remove();

    var ols = $(editor).find("ol");
    ols.css("margin","10px 0 10px 9%");
    ols.css("width","82%");
    ols.css("line-height","27px");
    ols.css("font-size","17px");
    ols.css("color","#323232");
    ols.css("list-style","decimal");

    RE.getStatus(RE.getElem().parentNode);
    RE.callback();
};

RE.setTextColor = function(color) {
    RE.restorerange();
    //document.execCommand("styleWithCSS", null, true);
    document.execCommand('foreColor', false, color);
    //document.execCommand("styleWithCSS", null, false);

    RE.callback();
};

RE.setTextBackgroundColor = function(color) {
    RE.restorerange();
    document.execCommand("styleWithCSS", null, true);
    document.execCommand('hiliteColor', false, color);
    document.execCommand("styleWithCSS", null, false);
};

RE.setFontSize = function(fontSize){
    document.execCommand("fontSize", false, fontSize);
};

RE.setHeading = function(heading) {
    document.execCommand('formatBlock', false, '<h'+heading+'>');
    var editor = $("#editor");

    editor.find("h1").css("font-size","24px");
    editor.find("h1").css("font-weight","bold");
    editor.find("h1").css("border-left","0");
    editor.find("h1").css("color","#323232");
    editor.find("h1").css("width","92%");
    editor.find("h1").css("margin","10px 0 10px 4%");

    editor.find("h2").css("font-size","20px");
    editor.find("h2").css("font-weight","bold");
    editor.find("h2").css("border-left","0");
    editor.find("h2").css("color","#323232");
    editor.find("h2").css("width","92%");
    editor.find("h2").css("margin","10px 0 10px 4%");

    editor.find("h3").css("font-size","18px");
    editor.find("h3").css("font-weight","bold");
    editor.find("h3").css("border-left","0");
    editor.find("h3").css("color","#323232");
    editor.find("h3").css("width","92%");
    editor.find("h3").css("margin","10px 0 10px 4%");

    RE.getStatus(RE.getElem().parentNode);
    RE.callback();
};

RE.setNormalContent = function() {
    document.execCommand('formatBlock', false, '<p>');
    var $selectionElem = $(RE.getElem()).parent();
    $selectionElem.css("line-height","27px");
    $selectionElem.css("font-size","17px");
    $selectionElem.css("color","#323232");
    $selectionElem.css("width","92%");
    $selectionElem.css("margin","10px 0 10px 4%");
    $selectionElem.css("font-weight","normal");
    $selectionElem.css("border-left","0");

    RE.getStatus($selectionElem[0]);
    RE.callback();
};

RE.setDescriptionType = function() {
    document.execCommand('formatBlock', false, '<p>');
    var $selectionElem = $(RE.getElem()).parent();
    $selectionElem.css("line-height","27px");
    $selectionElem.css("font-size","13px");
    $selectionElem.css("color","#969696");
    $selectionElem.css("width","92%");
    $selectionElem.css("margin","10px 0 10px 4%");
    $selectionElem.css("font-weight","normal");
    $selectionElem.css("border-left","0");

    RE.getStatus($selectionElem[0]);
    RE.callback();
};

RE.Indent = function() {
    //document.execCommand('outdent', false, null);
    var elem = RE.getElem().parentNode;
    if (elem.style.textIndent == '2em') {
        elem.style.textIndent = '0';
    } else {
        elem.style.textIndent = '2em';
    }
    if(elem.style.textAlign != "left"){
        elem.style.textAlign = "left";
    }

    RE.callback();
};

RE.setJustifyLeft = function() {
    document.execCommand('justifyLeft', false, null);
    var elem = RE.getElem().parentNode;
    elem.style.textIndent = '0';

    RE.callback();
};

RE.setJustifyCenter = function() {
    document.execCommand('justifyCenter', false, null);
    var elem = RE.getElem().parentNode;
    elem.style.textIndent = '0';

    RE.callback();
};

RE.setJustifyRight = function() {
    document.execCommand('justifyRight', false, null);
    var elem = RE.getElem().parentNode;
    elem.style.textIndent = '0';

    RE.callback();
};

RE.setBlockquote = function() {
    //document.execCommand('formatBlock', false, '<blockquote>');
    var $selectionElem = RE.getElem().parentNode;
    var nodeName = $selectionElem.nodeName;
    var content = void 0,
        $targetELem = void 0;
    if (nodeName === 'BLOCKQUOTE') {
        // 撤销 quote
        /*content = $($selectionElem).html();
         $targetELem = $('<p style="line-height: 27px;font-size: 17px;color: #323232;width: 92%;margin: 10px 0 10px 4%;">' + content + '</p>');
         $targetELem.insertAfter($selectionElem);
         $selectionElem.remove();*/
        return;
    }
    if (nodeName === 'P' || nodeName === 'H1' || nodeName === 'H2' || nodeName === 'H3') {
        // 将 P 转换为 quote
        content = $($selectionElem).html();
        $targetELem = $('<blockquote style="display: block;border-left: 8px solid #DEDDDD;padding: 5px 10px;margin: 10px 0 10px 4%;line-height: 27px;font-size: 17px;background-color: #ffffff;color: #969696;width: 86%;">' + content + '</blockquote>');
        $targetELem.insertAfter($selectionElem);
        $selectionElem.remove();
        RE.callback();
        RE.getStatus(RE.getElem().parentNode);
        return;
    }

    RE.getStatus(RE.getElem().parentNode);
    RE.callback();
};

RE.insertImage = function(url, alt) {
    var html = '<img src="' + url + '" alt="' + alt + '" />';
    RE.insertHTML(html);
};

RE.equal = function equal($elem) {
    if ($elem.nodeType === 1) {
        return this[0] === $elem;
    } else {
        return this[0] === $elem[0];
    }
};

RE.insertHTML = function(html) {
    RE.restorerange();
    document.execCommand('insertHTML', false, html);

    RE.callback();
};

RE.insertLink = function(url, title) {
    RE.restorerange();
    var sel = document.getSelection();
    if (sel.toString().length == 0) {
        document.execCommand("insertHTML",false,"<a href='"+url+"'>"+title+"</a>");
    } else if (sel.rangeCount) {
       var el = document.createElement("a");
       el.setAttribute("href", url);
       el.setAttribute("title", title);

       var range = sel.getRangeAt(0).cloneRange();
       range.surroundContents(el);
       sel.removeAllRanges();
       sel.addRange(range);
   }
    RE.callback();
};

RE.insertHorizontalRule = function() {
    RE.insertHTML('<hr style="margin: 5px 0 5px 4%;width: 92%;"><p style="line-height: 27px;font-size: 17px;color: #323232;width: 92%;margin: 10px 0 10px 4%;"><br></p>');

    RE.callback();
};

RE.setTodo = function(text) {
    var html = '<input type="checkbox" name="'+ text +'" value="'+ text +'"/> &nbsp;';
    document.execCommand('insertHTML', false, html);
};


RE.analysis = function(text) {
    var html = '<input type="checkbox" name="'+ text +'" value="'+ text +'"/> &nbsp;';
    document.execCommand('insertHTML', false, html);
};

RE.prepareInsert = function() {
    RE.backuprange();
};

RE.backuprange = function(){
    var selection = window.getSelection();
    if (selection.rangeCount > 0) {
      var range = selection.getRangeAt(0);
      RE.currentSelection = {
          "startContainer": range.startContainer,
          "startOffset": range.startOffset,
          "endContainer": range.endContainer,
          "endOffset": range.endOffset};
    }
};

RE.restorerange = function(){
    var selection = window.getSelection();
    selection.removeAllRanges();
    var range = document.createRange();
    range.setStart(RE.currentSelection.startContainer, RE.currentSelection.startOffset);
    range.setEnd(RE.currentSelection.endContainer, RE.currentSelection.endOffset);
    selection.addRange(range);
};

RE.enabledEditingItems = function(e) {
    var items = [];
    if (document.queryCommandState('bold')) {
        items.push('bold');
    }
    if (document.queryCommandState('italic')) {
        items.push('italic');
    }
    if (document.queryCommandState('subscript')) {
        items.push('subscript');
    }
    if (document.queryCommandState('superscript')) {
        items.push('superscript');
    }
    if (document.queryCommandState('strikeThrough')) {
        items.push('strikeThrough');
    }
    if (document.queryCommandState('underline')) {
        items.push('underline');
    }
    if (document.queryCommandState('insertOrderedList')) {
        items.push('orderedList');
    }
    if (document.queryCommandState('insertUnorderedList')) {
        items.push('unorderedList');
    }
    if (document.queryCommandState('justifyCenter')) {
        items.push('justifyCenter');
    }
    if (document.queryCommandState('justifyFull')) {
        items.push('justifyFull');
    }
    if (document.queryCommandState('justifyLeft')) {
        items.push('justifyLeft');
    }
    if (document.queryCommandState('justifyRight')) {
        items.push('justifyRight');
    }
    if (document.queryCommandState('insertHorizontalRule')) {
        items.push('horizontalRule');
    }
    var formatBlock = document.queryCommandValue('formatBlock');
    if (formatBlock.length > 0) {
        items.push(formatBlock);
    }

    window.location.href = "re-state://" + encodeURI(items.join(','));
};

RE.focus = function() {
    var range = document.createRange();
    range.selectNodeContents(RE.editor);
    range.collapse(false);
    var selection = window.getSelection();
    selection.removeAllRanges();
    selection.addRange(range);
    RE.editor.focus();
};

RE.blurFocus = function() {
    RE.editor.blur();
};

RE.removeFormat = function() {
    document.execCommand('removeFormat', false, null);
};

RE.titleElemCallback = function() {
    window.location.href = "re-titlecallback://" + encodeURI(RE.getTitle());
};
RE.descriptionElemCallback = function() {
    window.location.href = "re-descriptioncallback://" + encodeURI(RE.getDescription());
};

// Event Listeners
var titleElem = document.getElementById("title");
var descriptionElem = document.getElementById("description");
titleElem.addEventListener("input", RE.titleElemCallback);
descriptionElem.addEventListener("input", RE.descriptionElemCallback);

RE.editor.addEventListener("input", RE.callback);
RE.editor.addEventListener("keyup", function(e) {
    var KEY_LEFT = 37, KEY_RIGHT = 39;
    if (e.which == KEY_LEFT || e.which == KEY_RIGHT) {
        RE.enabledEditingItems(e);
    }
});
RE.editor.addEventListener("click", RE.enabledEditingItems);

RE.getElem = function() {
    var selection = window.getSelection();
    if (selection.rangeCount === 0) {
        return;
    }
    var range = selection.getRangeAt(0);
    var elem = void 0;
    if (range) {
        elem = range.commonAncestorContainer;
        return elem;
    }
};

RE.selectionElem = null;
RE.setSelectionElem = function(){
    RE.selectionElem = $(RE.getElem());
};

RE.insertSource = function(type,url,bgUrl) {
    var $selectionElem;
    if(RE.selectionElem != null){
        $selectionElem = RE.selectionElem;
    }else{
        $selectionElem = $(RE.getElem());
    }
    var elem;
    if($selectionElem.parent().attr("id") == "editor"){
        elem = $selectionElem;
    }else{
        elem = $selectionElem.parent();
        if(elem.parent().attr("id") != "editor"){
            elem = $selectionElem.parent();
            if(elem.parent().attr("id") != "editor"){
                elem = $selectionElem.parent();
                if(elem.parent().attr("id") != "editor"){
                    elem = $selectionElem.parent();
                }
            }
        }
    }
    var randomNum = rndNum(9);
    var html = "";
    var clientWidth = window.screen.width;
    if(type == 1){
        html = '<div class="editSource" style="width: 92%;margin-left: 4%;margin-bottom: 20px;margin-top: 20px;position: relative;" bgKey="" alikey="" id="'+randomNum+'"><img src="img/deleteReporter.png" class="deleteSource"><img src="'+url+'" style="max-width: 100%;margin: 0 auto;max-height: '+clientWidth*0.92*9/16+'px" class="videoSource"/><p class="sourceDes" contenteditable="false" style="font-size: 14px;color: #969696;border-bottom: 1px solid #DCDCDC;padding: 0 4%;margin: 12px auto 0 auto;width: 92%;text-align: center;cursor: pointer;">点击输入素材描述</p><div class="mask"><img src="img/reUpload.png" class="reUpload"></div></div>';
    }else if(type == 3){
        html = '<div class="editSource" style="width: 92%;margin-left: 4%;margin-bottom: 20px;margin-top: 20px;position: relative;" bgKey="" alikey="" id="'+randomNum+'"><img src="img/deleteReporter.png" class="deleteSource" style="top: 2px;"><audio src="'+url+'" controls="controls" style="width: 90%;" class="videoSource"></audio><p class="sourceDes" contenteditable="false" style="font-size: 14px;color: #969696;border-bottom: 1px solid #DCDCDC;padding: 0 4%;margin: 12px auto 0 auto;width: 92%;text-align: center;cursor: pointer;">点击输入素材描述</p><div class="mask"><img src="img/reUpload.png" class="reUpload"></div></div>';
    }else if(type == 0){
        html = '<div class="editSource" style="width: 92%;margin-left: 4%;margin-bottom: 20px;margin-top: 20px;position: relative;" bgKey="" alikey="" id="'+randomNum+'"><img src="img/deleteReporter.png" class="deleteSource"><video src="'+url+'" style="width: 100%;height: '+clientWidth*0.92*9/16+'px" class="videoSource" poster="'+bgUrl+'" controlsList="nodownload"></video><img src="img/audioStart.png" class="videoSourceBg" style="width: 40px;height: 40px;position: absolute;left: 50%;top: '+clientWidth*0.92*9/32+'px;margin: -20px 0 0 -20px;"><p class="sourceDes" contenteditable="false" style="font-size: 14px;color: #969696;border-bottom: 1px solid #DCDCDC;padding: 0 4%;margin: 12px auto 0 auto;width: 92%;text-align: center;cursor: pointer;">点击输入素材描述</p><div class="mask"><img src="img/reUpload.png" class="reUpload"></div></div>';
    }
    if(elem.next().length == 0){
        html += '<p style="line-height: 27px;font-size: 17px;color: #323232;width: 92%;margin: 10px 0 10px 4%;"><br></p>';
    }
    $(html).insertAfter(elem);
    $(".editSource").attr("contenteditable","false");
    $(".deleteSource").attr("contenteditable","false");
    $(".videoSource").attr("contenteditable","false").bind('play', function(){
        //alert('开始播放');
    }).bind('ended', function(){
        //alert('结束');
    }).bind('pause', function(){
        //alert('暂停');
    });
    $(".sourceDes").attr("contenteditable","false");
    $(".mask").attr("contenteditable","false");
    $(".reUpload").attr("contenteditable","false");
    $(".videoSourceBg").attr("contenteditable","false");
    RE.callback();
    return randomNum;
};

RE.sourceUpload = function(randomNum,alikey,bgKey) {
    var editSource = $(".editSource");
    var whichLoader = null;
    for(var j=0,maxj=editSource.length;j<maxj;j++){
        if($(editSource[j]).attr("id") == randomNum){
            whichLoader = $(editSource[j]);
            whichLoader.find(".mask").remove();
            break;
        }
    }
    if(whichLoader != null){
        whichLoader.attr("bgKey",bgKey);
        whichLoader.attr("alikey",alikey);
        whichLoader.find(".videoSource").attr("src","http://img.baoxinwen.com/"+alikey);
        whichLoader.find("video.videoSource").attr("poster","http://img.baoxinwen.com/"+bgKey);
        RE.callback();
    }
};

RE.uploadError = function(id){
    var editSource = $(".editSource");
    for(var j=0,maxj=editSource.length;j<maxj;j++){
        if($(editSource[j]).attr("id") == id){
            $(editSource[j]).find(".mask").show();
            break;
        }
    }

    RE.callback();
};

RE.setTitle = function(title){
    $("#title").html(title);
    RE.titleElemCallback();
};

RE.getTitle = function(){
    var title = $("#title").html();
    if(title == "请输入标题"){
        title = "";
    }
    return title;
};

RE.setDescription = function(description){
    $("#description").html(description);
    RE.descriptionElemCallback();
};

RE.getDescription = function(){
    var description = $("#description").html();
    if(description == "请输入导语"){
        description = "";
    }
    return description;
};

RE.setContentById = function(id,type){
    if(type == 0){
        var request = {
            scriptId: id
        };
        var cfg = {
            type: 'POST',
            data: JSON.stringify(request),
            dataType: 'json',
            contentType: 'application/json;',
            success: function (result) {
                if (result.errorCode == 0){
                    RE.setContent(result.scriptDetail.clips[0].description);
                }
            }
        };
        cfg.url = "/json/script/getAllDetailByScriptId.json";
        $.ajax(cfg);
    }else{
        var cfgDraft = {
            type: 'GET',
            dataType: 'json',
            contentType: 'application/json;',
            success: function (result) {
                if (result.errorCode == 0){
                    RE.setContent(result.clips[0].description);
                }
            }
        };
        cfgDraft.url = "/news/script/draft/personal/v1/get/" + id + ".json";
        $.ajax(cfgDraft);
    }
};

RE.setContent = function(content){
    var u = navigator.userAgent;
    var isiOS = !!u.match(/\(i[^;]+;( U;)? CPU.+Mac OS X/); //ios终端
    if(isiOS){
        var b = new RE.Base64();
        content = b.decode(content);
    }
    var container = $("#editor");
    container.html(content);
    container.find("ol").css({"width":"82%","margin":"10px 0 10px 9%"});
    container.find("ul").css({"width":"82%","margin":"10px 0 10px 9%"});
    var editSource = container.find(".editSource");
    editSource.prepend('<img src="img/deleteReporter.png" class="deleteSource">');
    for(var k=0,maxk=editSource.length;k<maxk;k++){
        if($(editSource[k]).find(".sourceDes").length == 0){
            $(editSource[k]).append('<p class="sourceDes" contenteditable="false" style="font-size: 14px;color: #969696;border-bottom: 1px solid #DCDCDC;padding: 0 4%;margin: 12px auto 0 auto;width: 92%;text-align: center;cursor: pointer;">点击输入素材描述</p>');
        }else{
            var sourceDes = $(editSource[k]).find(".sourceDes");
            sourceDes.css({"border-bottom":"1px solid #DCDCDC"}).attr("contenteditable","false");
        }
    }
    container.find("audio").css({"width":"90%"});
    var clientWidth = window.screen.width;
    container.find("video.videoSource").attr("controls",false).css({"max-height":clientWidth*0.92*9/16+"px"});
    container.find("img.videoSource").css({"max-height":clientWidth*0.92*9/16+"px"});
    $('<img src="img/audioStart.png" class="videoSourceBg" style="width: 40px;height: 40px;position: absolute;left: 50%;top: '+clientWidth*0.92*9/32+'px;margin: -20px 0 0 -20px;">').insertAfter($("video.videoSource"));
    container.find("ol").css("list-style","decimal");
    container.find("ul").css("list-style","disc");
    RE.callback();
};

RE.getContent = function(){
    var container = $("#previewContainer");
    container.empty().append($("#editor").html());
    container.find(".deleteSource").remove();
    container.find("ol").css({"margin":"10px 0 10px 6.5%","width":"87%"});
    container.find("ul").css({"margin":"10px 0 10px 6.5%","width":"87%"});
    var sourceDes = container.find(".sourceDes");
    for(var k=0,maxk=sourceDes.length;k<maxk;k++){
        if($(sourceDes[k]).html() == "点击输入素材描述"){
            $(sourceDes[k]).remove();
        }
    }
    sourceDes.css({"border-bottom":"0"});
    container.find("audio").css({"width":"100%"});
    container.find(".reUpload").parents(".editSource").remove();
    container.find("img.videoSource").css({"max-height":"auto","display":"block"});
    container.find("video.videoSource").attr("controls",true).css({"max-height":"auto","display":"block"});
    container.find(".videoSourceBg").remove();
    container.find("ol").css("list-style","decimal");
    container.find("ul").css("list-style","disc");
    return container.html();
};

RE.getStatus = function(thisElem){
    var stateQuery = {
        bold: false,
        italic: false,
        underline: false,
        strikeThrough: false,
        h1: false,
        h2: false,
        h3: false,
        quote: false,
        normal: false,
        description: false,
        justifyLeft: false,
        justifyCenter: false,
        justifyRight: false,
        hasIndent: false,
        orderedList: false,
        unorderedList: false,
        fontColor: ""
    };
    if(document.queryCommandState("bold")){
        stateQuery.bold = true;
    }
    if(document.queryCommandState("italic")){
        stateQuery.italic = true;
    }
    if(document.queryCommandState("underline")){
        stateQuery.underline = true;
    }
    if(document.queryCommandState("strikeThrough")){
        stateQuery.strikeThrough = true;
    }
    if(/^h1/i.test(document.queryCommandValue("formatBlock"))){
        stateQuery.h1 = true;
    }
    if(/^h2/i.test(document.queryCommandValue("formatBlock"))){
        stateQuery.h2 = true;
    }
    if(/^h3/i.test(document.queryCommandValue("formatBlock"))){
        stateQuery.h3 = true;
    }
    if(/^BLOCKQUOTE$/i.test(document.queryCommandValue("formatBlock"))){
        stateQuery.quote = true;
    }
    if(/^P/i.test(document.queryCommandValue("formatBlock")) && thisElem.style.fontSize == "17px"){
        stateQuery.normal = true;
    }
    if(/^P/i.test(document.queryCommandValue("formatBlock")) && thisElem.style.fontSize == "13px"){
        stateQuery.description = true;
    }
    if(document.queryCommandState("justifyLeft")){
        stateQuery.justifyLeft = true;
    }
    if(document.queryCommandState("justifyCenter")){
        stateQuery.justifyCenter = true;
    }
    if(document.queryCommandState("justifyRight")){
        stateQuery.justifyRight = true;
    }
    if (thisElem.style.textIndent == '2em') {
        stateQuery.hasIndent = true;
    }
    if(document.queryCommandState("insertOrderedList")){
        stateQuery.orderedList = true;
    }
    if(document.queryCommandState("insertUnorderedList")){
        stateQuery.unorderedList = true;
    }
    stateQuery.fontColor = colorRGB2Hex(thisElem.style.color);
    var u = navigator.userAgent;
    var isAndroid = u.indexOf('Android') > -1 || u.indexOf('Adr') > -1; //android终端
    var isiOS = !!u.match(/\(i[^;]+;( U;)? CPU.+Mac OS X/); //ios终端
    if(isAndroid){
        Android.getAttributesByCursor(JSON.stringify(stateQuery));
    }else if(isiOS){
        getAttributesByCursor(JSON.stringify(stateQuery));
    }
};

RE.stopVoice = function(){
    var audio = $("audio");
    for(var i=0,max=audio.length;i<max;i++){
        audio[i].pause();
    }
    var video = $("video");
    for(var j=0,maxj=video.length;j<maxj;j++){
        video[j].pause();
    }
};

RE.Base64 = function(){

    // private property
    var _keyStr = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=";

    // public method for encoding
    this.encode = function (input) {
        var output = "";
        var chr1, chr2, chr3, enc1, enc2, enc3, enc4;
        var i = 0;
        input = _utf8_encode(input);
        while (i < input.length) {
            chr1 = input.charCodeAt(i++);
            chr2 = input.charCodeAt(i++);
            chr3 = input.charCodeAt(i++);
            enc1 = chr1 >> 2;
            enc2 = ((chr1 & 3) << 4) | (chr2 >> 4);
            enc3 = ((chr2 & 15) << 2) | (chr3 >> 6);
            enc4 = chr3 & 63;
            if (isNaN(chr2)) {
                enc3 = enc4 = 64;
            } else if (isNaN(chr3)) {
                enc4 = 64;
            }
            output = output +
                _keyStr.charAt(enc1) + _keyStr.charAt(enc2) +
                _keyStr.charAt(enc3) + _keyStr.charAt(enc4);
        }
        return output;
    };

    // public method for decoding
    this.decode = function (input) {
        var output = "";
        var chr1, chr2, chr3;
        var enc1, enc2, enc3, enc4;
        var i = 0;
        input = input.replace(/[^A-Za-z0-9\+\/\=]/g, "");
        while (i < input.length) {
            enc1 = _keyStr.indexOf(input.charAt(i++));
            enc2 = _keyStr.indexOf(input.charAt(i++));
            enc3 = _keyStr.indexOf(input.charAt(i++));
            enc4 = _keyStr.indexOf(input.charAt(i++));
            chr1 = (enc1 << 2) | (enc2 >> 4);
            chr2 = ((enc2 & 15) << 4) | (enc3 >> 2);
            chr3 = ((enc3 & 3) << 6) | enc4;
            output = output + String.fromCharCode(chr1);
            if (enc3 != 64) {
                output = output + String.fromCharCode(chr2);
            }
            if (enc4 != 64) {
                output = output + String.fromCharCode(chr3);
            }
        }
        output = _utf8_decode(output);
        return output;
    };

    // private method for UTF-8 encoding
    _utf8_encode = function (string) {
        string = string.replace(/\r\n/g,"\n");
        var utftext = "";
        for (var n = 0; n < string.length; n++) {
            var c = string.charCodeAt(n);
            if (c < 128) {
                utftext += String.fromCharCode(c);
            } else if((c > 127) && (c < 2048)) {
                utftext += String.fromCharCode((c >> 6) | 192);
                utftext += String.fromCharCode((c & 63) | 128);
            } else {
                utftext += String.fromCharCode((c >> 12) | 224);
                utftext += String.fromCharCode(((c >> 6) & 63) | 128);
                utftext += String.fromCharCode((c & 63) | 128);
            }

        }
        return utftext;
    };

    // private method for UTF-8 decoding
    _utf8_decode = function (utftext) {
        var string = "";
        var i = 0;
        var c = c1 = c2 = 0;
        while ( i < utftext.length ) {
            c = utftext.charCodeAt(i);
            if (c < 128) {
                string += String.fromCharCode(c);
                i++;
            } else if((c > 191) && (c < 224)) {
                c2 = utftext.charCodeAt(i+1);
                string += String.fromCharCode(((c & 31) << 6) | (c2 & 63));
                i += 2;
            } else {
                c2 = utftext.charCodeAt(i+1);
                c3 = utftext.charCodeAt(i+2);
                string += String.fromCharCode(((c & 15) << 12) | ((c2 & 63) << 6) | (c3 & 63));
                i += 3;
            }
        }
        return string;
    }
};